ExpandTileController class

A controller that manages the expansion state and content of an expandable tile.

Inheritance

Constructors

ExpandTileController()

Properties

axisExpand AxisExpand
The direction in which the tile expands.
no setter
expanded Widget?
The children which can be expanded.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isExpand bool
Whether the tile is currently expanded.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
The title will show and can be toggle
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setAxisExpand(AxisExpand axisExpand) → void
setExpanded(Widget? expanded) → void
setIsExpand(bool isExpand) → void
setTitle(String title) → void
toggleExpand() → void
action change status expandable
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited