ExpandableCustomView class

The custom widget usage

Inheritance

Constructors

ExpandableCustomView.animatedDef({required Widget title, required Widget child, AxisExpand axis = AxisExpand.vertical, Ratio ratio = const Ratio(5, 5), bool posHorizontal = false})
Animation Default (Size)
factory
ExpandableCustomView.animatedFade({required Widget title, required Widget child, Ratio ratio = const Ratio(5, 5), bool posHorizontal = false})
Animation Fade
factory
ExpandableCustomView.animatedScale({required Widget title, required Widget child, Ratio ratio = const Ratio(5, 5), bool posHorizontal = false})
Animation Scale
factory
ExpandableCustomView.noneAnimation({required Widget title, required Widget child, Ratio ratio = const Ratio(5, 5), bool posHorizontal = false})
No animation
factory

Properties

animationType ExpandableAnimation
final
axis AxisExpand
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
posHorizontal bool
final
ratio Ratio
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ExpandableCustomView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited