ExpandableImageView class

The main widget Image usage

Inheritance

Constructors

ExpandableImageView.animatedDef({required String src, required Widget child, AxisExpand axis = AxisExpand.vertical, Color? titleBGColor, TextStyle? titleTextStyle, bool posHorizontal = false})
Animation Default (Size)
factory
ExpandableImageView.animatedFade({required String src, required Widget child, Color? titleBGColor, TextStyle? titleTextStyle, bool posHorizontal = false})
Animation Fade
factory
ExpandableImageView.animatedScale({required String src, required Widget child, Color? titleBGColor, TextStyle? titleTextStyle, bool posHorizontal = false})
Animation Scale
factory
ExpandableImageView.noneAnimation({required String src, required Widget child, Color? titleBGColor, TextStyle? titleTextStyle, bool posHorizontal = false})
No animation
factory

Properties

animationType ExpandableAnimation
final
axis AxisExpand
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
posHorizontal bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String
final
titleBGColor Color?
final
titleTextStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ExpandableImageView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited