Ratio class

The model ratio help for horizontal widget

Constructors

Ratio(int left, int right)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
left int
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
ratio value double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override